# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.application_config import ApplicationConfig  # noqa: E501
from agilicus_api.rest import ApiException

class TestApplicationConfig(unittest.TestCase):
    """ApplicationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApplicationConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.application_config.ApplicationConfig()  # noqa: E501
        if include_optional :
            return ApplicationConfig(
                authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                    application_handles_authentication = False, 
                    session_secret = 'Gns5ZPCvXGjzrtB672HAxfoSQ0dmqriSgiQf6uEQSBU=', ), 
                oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                    headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                        domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                            standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                location = True, 
                                origin = True, 
                                host = True, ), 
                            other_headers = [
                                agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                    name = 'Accept-Encoding', 
                                    value = '*', )
                                ], ), 
                        header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                            request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                set = [
                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                        name = 'Accept-Encoding', 
                                        value = '*', )
                                    ], 
                                add = [
                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                        name = 'Accept-Encoding', 
                                        value = '*', )
                                    ], 
                                remove = [
                                    agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                        name = '0', )
                                    ], ), 
                            response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                    domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                        primary_external_name = 'app-1.cloud.egov.city', 
                        primary_internal_name = 'app-1.internal', 
                        other_mappings = [
                            agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                internal_name = 'local_test_app', 
                                external_name = 'app-1', )
                            ], ), 
                    auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                        auth_enabled = True, 
                        client_id = 'admin-portal', 
                        issuer = 'https://auth.cloud.egov.city', 
                        logout_url = '/login/logout.cfm', 
                        scopes = [
                            agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                name = 'urn:agilicus:app:app-1:owner', )
                            ], 
                        path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                            included_paths = [{"path":"/login"}], 
                            excluded_paths = [{"path":"/logout"}], ), ), 
                    content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                        media_types = [
                            agilicus_api.models.oidc_content_type.OIDCContentType(
                                name = 'text/css', )
                            ], ), 
                    upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                        scheme = 'https', 
                        hostname = 'httpbin.org', ), )
            )
        else :
            return ApplicationConfig(
        )

    def testApplicationConfig(self):
        """Test ApplicationConfig"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ResourceStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'resource_id': 'str',
        'metadata': 'ResourceStatsMetadata',
        'overall_status': 'str',
        'last_warning_message': 'str',
        'session_stats': 'ResourceSessionStats'
    }

    attribute_map = {
        'resource_id': 'resource_id',
        'metadata': 'metadata',
        'overall_status': 'overall_status',
        'last_warning_message': 'last_warning_message',
        'session_stats': 'session_stats'
    }

    def __init__(self, resource_id=None, metadata=None, overall_status=None, last_warning_message=None, session_stats=None, local_vars_configuration=None):  # noqa: E501
        """ResourceStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._resource_id = None
        self._metadata = None
        self._overall_status = None
        self._last_warning_message = None
        self._session_stats = None
        self.discriminator = None

        if resource_id is not None:
            self.resource_id = resource_id
        if metadata is not None:
            self.metadata = metadata
        if overall_status is not None:
            self.overall_status = overall_status
        if last_warning_message is not None:
            self.last_warning_message = last_warning_message
        if session_stats is not None:
            self.session_stats = session_stats

    @property
    def resource_id(self):
        """Gets the resource_id of this ResourceStats.  # noqa: E501

        The unique ID of the resource. The id is provided here so that a list of resource stats can be POSTed in a single request.   # noqa: E501

        :return: The resource_id of this ResourceStats.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """Sets the resource_id of this ResourceStats.

        The unique ID of the resource. The id is provided here so that a list of resource stats can be POSTed in a single request.   # noqa: E501

        :param resource_id: The resource_id of this ResourceStats.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def metadata(self):
        """Gets the metadata of this ResourceStats.  # noqa: E501


        :return: The metadata of this ResourceStats.  # noqa: E501
        :rtype: ResourceStatsMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ResourceStats.


        :param metadata: The metadata of this ResourceStats.  # noqa: E501
        :type: ResourceStatsMetadata
        """

        self._metadata = metadata

    @property
    def overall_status(self):
        """Gets the overall_status of this ResourceStats.  # noqa: E501

        The summary status of the Resource. - A `good` status means that no action is neccessary on this Resource  - A `warn` status means that there is an issue that should be dealt with   Examples include a forwarder resource that cannot bind to the provisioned port (eg. permission   issue binding to port 80) - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Resource's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector containing the resource.   # noqa: E501

        :return: The overall_status of this ResourceStats.  # noqa: E501
        :rtype: str
        """
        return self._overall_status

    @overall_status.setter
    def overall_status(self, overall_status):
        """Sets the overall_status of this ResourceStats.

        The summary status of the Resource. - A `good` status means that no action is neccessary on this Resource  - A `warn` status means that there is an issue that should be dealt with   Examples include a forwarder resource that cannot bind to the provisioned port (eg. permission   issue binding to port 80) - A `down` status indicates that there is a service accessibility problem   that should be dealt with as soon as possible. This could mean that there is a   problem with the Resource's configuration, or the platform. - A `stale` status indicates that although there may not be anything wrong,   we haven't been able to update the status recently. This may indicate   a communications issue between Agilicus and the Connector containing the resource.   # noqa: E501

        :param overall_status: The overall_status of this ResourceStats.  # noqa: E501
        :type: str
        """

        self._overall_status = overall_status

    @property
    def last_warning_message(self):
        """Gets the last_warning_message of this ResourceStats.  # noqa: E501

        A message pertaining to the last warning associated with the resource. This message is persistent in that it will remain when the status goes to `good`.   # noqa: E501

        :return: The last_warning_message of this ResourceStats.  # noqa: E501
        :rtype: str
        """
        return self._last_warning_message

    @last_warning_message.setter
    def last_warning_message(self, last_warning_message):
        """Sets the last_warning_message of this ResourceStats.

        A message pertaining to the last warning associated with the resource. This message is persistent in that it will remain when the status goes to `good`.   # noqa: E501

        :param last_warning_message: The last_warning_message of this ResourceStats.  # noqa: E501
        :type: str
        """

        self._last_warning_message = last_warning_message

    @property
    def session_stats(self):
        """Gets the session_stats of this ResourceStats.  # noqa: E501


        :return: The session_stats of this ResourceStats.  # noqa: E501
        :rtype: ResourceSessionStats
        """
        return self._session_stats

    @session_stats.setter
    def session_stats(self, session_stats):
        """Sets the session_stats of this ResourceStats.


        :param session_stats: The session_stats of this ResourceStats.  # noqa: E501
        :type: ResourceSessionStats
        """

        self._session_stats = session_stats

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResourceStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.mfa_enrollment_answer import MFAEnrollmentAnswer  # noqa: E501
from agilicus_api.rest import ApiException

class TestMFAEnrollmentAnswer(unittest.TestCase):
    """MFAEnrollmentAnswer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MFAEnrollmentAnswer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.mfa_enrollment_answer.MFAEnrollmentAnswer()  # noqa: E501
        if include_optional :
            return MFAEnrollmentAnswer(
                result = agilicus_api.models.mfa_enrollment_answer_result.MFAEnrollmentAnswerResult(
                    action = 'enroll', 
                    supported_mfa_methods = ["totp","webauthn"], )
            )
        else :
            return MFAEnrollmentAnswer(
                result = agilicus_api.models.mfa_enrollment_answer_result.MFAEnrollmentAnswerResult(
                    action = 'enroll', 
                    supported_mfa_methods = ["totp","webauthn"], ),
        )

    def testMFAEnrollmentAnswer(self):
        """Test MFAEnrollmentAnswer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_connector_response import ListConnectorResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListConnectorResponse(unittest.TestCase):
    """ListConnectorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListConnectorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_connector_response.ListConnectorResponse()  # noqa: E501
        if include_optional :
            return ListConnectorResponse(
                connectors = [
                    agilicus_api.models.connector.Connector(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.connector_spec.ConnectorSpec(
                            name = '0', 
                            name_slug = 'a', 
                            org_id = '123', 
                            connector_type = 'agent', 
                            service_account_id = '0', ), 
                        status = agilicus_api.models.connector_status.ConnectorStatus(
                            application_services = [
                                agilicus_api.models.application_service.ApplicationService(
                                    created = '2015-07-07T15:49:51.230+02:00', 
                                    id = '123', 
                                    name = 'my-local-service', 
                                    org_id = '0', 
                                    hostname = 'db.example.com', 
                                    ipv4_addresses = [
                                        '192.0.2.1'
                                        ], 
                                    name_resolution = 'static', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    assignments = [
                                        agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                            app_id = '0', 
                                            environment_name = '0', 
                                            org_id = '0', )
                                        ], 
                                    updated = '2015-07-07T15:49:51.230+02:00', 
                                    service_type = 'vpn', 
                                    service_protocol_type = 'ip', 
                                    tls_enabled = True, 
                                    tls_verify = True, 
                                    connector_id = '123', 
                                    connection_uri = '0', 
                                    stats = {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}, )
                                ], 
                            service_account_id = '0', 
                            stats = agilicus_api.models.connector_stats.ConnectorStats(
                                metadata = agilicus_api.models.connector_stats_metadata.ConnectorStatsMetadata(
                                    creation_time = '2020-07-07T15:40:46.010Z', 
                                    collection_time = '2020-07-07T15:49:51.230Z', 
                                    receipt_time = '2020-07-07T15:49:51.530Z', ), 
                                overall_status = 'good', 
                                forwarder_stats = [
                                    {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}
                                    ], 
                                app_service_stats = [
                                    {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}
                                    ], 
                                share_service_stats = [
                                    {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}
                                    ], 
                                diagnostic_stats = agilicus_api.models.connector_diagnostic_stats.ConnectorDiagnosticStats(
                                    generic_int_metrics = [
                                        agilicus_api.models.generic_int_metric.GenericIntMetric(
                                            name = 'gc_pauses_histogram_1.0', 
                                            value = 678382, )
                                        ], 
                                    generic_float_metrics = [
                                        agilicus_api.models.generic_float_metric.GenericFloatMetric(
                                            name = 'gc_pauses_histogram_1.0', 
                                            value = 1.5, )
                                        ], ), ), ), )
                    ], 
                limit = 56
            )
        else :
            return ListConnectorResponse(
                connectors = [
                    agilicus_api.models.connector.Connector(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.connector_spec.ConnectorSpec(
                            name = '0', 
                            name_slug = 'a', 
                            org_id = '123', 
                            connector_type = 'agent', 
                            service_account_id = '0', ), 
                        status = agilicus_api.models.connector_status.ConnectorStatus(
                            application_services = [
                                agilicus_api.models.application_service.ApplicationService(
                                    created = '2015-07-07T15:49:51.230+02:00', 
                                    id = '123', 
                                    name = 'my-local-service', 
                                    org_id = '0', 
                                    hostname = 'db.example.com', 
                                    ipv4_addresses = [
                                        '192.0.2.1'
                                        ], 
                                    name_resolution = 'static', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    assignments = [
                                        agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                            app_id = '0', 
                                            environment_name = '0', 
                                            org_id = '0', )
                                        ], 
                                    updated = '2015-07-07T15:49:51.230+02:00', 
                                    service_type = 'vpn', 
                                    service_protocol_type = 'ip', 
                                    tls_enabled = True, 
                                    tls_verify = True, 
                                    connector_id = '123', 
                                    connection_uri = '0', 
                                    stats = {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}, )
                                ], 
                            service_account_id = '0', 
                            stats = agilicus_api.models.connector_stats.ConnectorStats(
                                metadata = agilicus_api.models.connector_stats_metadata.ConnectorStatsMetadata(
                                    creation_time = '2020-07-07T15:40:46.010Z', 
                                    collection_time = '2020-07-07T15:49:51.230Z', 
                                    receipt_time = '2020-07-07T15:49:51.530Z', ), 
                                overall_status = 'good', 
                                forwarder_stats = [
                                    {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}
                                    ], 
                                app_service_stats = [
                                    {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}
                                    ], 
                                share_service_stats = [
                                    {"metadata":{"creation_time":"2020-07-07T15:40:46.010Z","collection_time":"2020-07-07T15:40:44.020Z","receipt_time":"2020-07-07T15:40:46.020Z"},"overall_status":"good"}
                                    ], 
                                diagnostic_stats = agilicus_api.models.connector_diagnostic_stats.ConnectorDiagnosticStats(
                                    generic_int_metrics = [
                                        agilicus_api.models.generic_int_metric.GenericIntMetric(
                                            name = 'gc_pauses_histogram_1.0', 
                                            value = 678382, )
                                        ], 
                                    generic_float_metrics = [
                                        agilicus_api.models.generic_float_metric.GenericFloatMetric(
                                            name = 'gc_pauses_histogram_1.0', 
                                            value = 1.5, )
                                        ], ), ), ), )
                    ],
                limit = 56,
        )

    def testListConnectorResponse(self):
        """Test ListConnectorResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.application_services_api import ApplicationServicesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestApplicationServicesApi(unittest.TestCase):
    """ApplicationServicesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.application_services_api.ApplicationServicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_application_service(self):
        """Test case for create_application_service

        Create an ApplicationService  # noqa: E501
        """
        pass

    def test_create_application_service_token(self):
        """Test case for create_application_service_token

        create a token for an application service  # noqa: E501
        """
        pass

    def test_create_file_share_service(self):
        """Test case for create_file_share_service

        Create an FileShareService  # noqa: E501
        """
        pass

    def test_create_service_forwarder(self):
        """Test case for create_service_forwarder

        Create an ServiceForwarder  # noqa: E501
        """
        pass

    def test_delete_application_service(self):
        """Test case for delete_application_service

        Remove an ApplicationService  # noqa: E501
        """
        pass

    def test_delete_file_share_service(self):
        """Test case for delete_file_share_service

        Remove an FileShareService  # noqa: E501
        """
        pass

    def test_delete_service_forwarder(self):
        """Test case for delete_service_forwarder

        Remove an ServiceForwarder  # noqa: E501
        """
        pass

    def test_get_application_service(self):
        """Test case for get_application_service

        Get a single ApplicationService  # noqa: E501
        """
        pass

    def test_get_application_service_usage_metrics(self):
        """Test case for get_application_service_usage_metrics

        Get application service metrics  # noqa: E501
        """
        pass

    def test_get_file_share_service(self):
        """Test case for get_file_share_service

        Get a single FileShareService  # noqa: E501
        """
        pass

    def test_get_file_share_usage_metrics(self):
        """Test case for get_file_share_usage_metrics

        Get file share service metrics  # noqa: E501
        """
        pass

    def test_get_service_forwarder(self):
        """Test case for get_service_forwarder

        Get a single ServiceForwarder  # noqa: E501
        """
        pass

    def test_list_application_services(self):
        """Test case for list_application_services

        Get a subset of the ApplicationServices  # noqa: E501
        """
        pass

    def test_list_file_share_services(self):
        """Test case for list_file_share_services

        Get a subset of the FileShareServices  # noqa: E501
        """
        pass

    def test_list_service_forwarders(self):
        """Test case for list_service_forwarders

        Get a subset of the ServiceForwarder objects  # noqa: E501
        """
        pass

    def test_replace_application_service(self):
        """Test case for replace_application_service

        Create or update an Application Service.  # noqa: E501
        """
        pass

    def test_replace_file_share_service(self):
        """Test case for replace_file_share_service

        Create or update an FileShareService.  # noqa: E501
        """
        pass

    def test_replace_service_forwarder(self):
        """Test case for replace_service_forwarder

        Create or update an ServiceForwarder.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
